/* 
 * linux/drvers/char/lpcid.h - kernel driver for caller id parallel port device
 *
 * Copyright (C) 1998  Juha Tuomala
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * <Juha.Tuomala@iki.fi> / Sateentie 4 A 32, 02100 ESPOO FINLAND
 */

/* General definitions */
#define LPCID_BUFFER_SIZE 256
#define LPCID_IRQ(minor) lpcid_table[(minor)].irq       /* interrupt */
#define LPCID_BASE(minor)       lpcid_table[(minor)].base       /* base address */
#define LPCID_STATUS(minor) (lpcid_table[(minor)].base + 1)     /* status       */
#define LPCID_CONTROL(minor) (lpcid_table[(minor)].base + 2)    /* control      */
#define LPCID_WAIT_Q(minor) (lpcid_table[(minor)].wait_q)
#define LPCID_CH(minor) (lpcid_table[(minor)].ch)
#define LPCID_CH_RECEIVED(minor) (lpcid_table[(minor)].character_received)
#define LPCID_MAJOR 6

/* Vcc on to all pins */
#define LPCID_VCC_ON    0xff
#define LPCID_VCC_OFF   0xff

/* Control commands for 8255  */
#define LPCID_PINTEN    0x10  /* high to read data in or-ed with data out */
#define LPCID_PSELECP   0x08  /* inverted output, active low */
#define LPCID_PINITP    0x04  /* unchanged output, active low */
#define LPCID_PAUTOLF   0x02  /* inverted output, active low */
#define LPCID_PSTROBE   0x01  /* short high output on raising edge */

/* IOCTL numbers */
#define LPCIDSETDEBUG   0x01  /* switches debugging mode on -> more logging */
#define LPCIDUNSETDEBUG 0x02  /* switches off debugging mode */
#define LPCIDGETIRQ     0x03  /* shows what irq is currently used */
#define LPCIDSETIRQ     0x04  /* changes irq to use */
#define LPCIDGETCSTATUS 0x05  /* shows status of control register */

extern int lpcid_init(void);

struct lpcid_struct {
  int base;
  int irq;
  wait_queue_head_t wait_q;
  int ch;
  int character_received;
};
